pub struct GenesisConfig {Show 13 fields
pub creation_time: UnixTimestamp,
pub accounts: BTreeMap<Pubkey, Account>,
pub native_instruction_processors: Vec<(String, Pubkey)>,
pub rewards_pools: BTreeMap<Pubkey, Account>,
pub ticks_per_slot: u64,
pub unused: u64,
pub poh_config: PohConfig,
pub __backwards_compat_with_v0_23: u64,
pub fee_rate_governor: FeeRateGovernor,
pub rent: Rent,
pub inflation: Inflation,
pub epoch_schedule: EpochSchedule,
pub cluster_type: ClusterType,
}Fields
creation_time: UnixTimestampwhen the network (bootstrap validator) was started relative to the UNIX Epoch
accounts: BTreeMap<Pubkey, Account>initial accounts
native_instruction_processors: Vec<(String, Pubkey)>built-in programs
rewards_pools: BTreeMap<Pubkey, Account>accounts for network rewards, these do not count towards capitalization
ticks_per_slot: u64unused: u64poh_config: PohConfignetwork speed configuration
__backwards_compat_with_v0_23: u64this field exists only to ensure that the binary layout of GenesisConfig remains compatible with the Cartallum CBE v0.23 release line
fee_rate_governor: FeeRateGovernortransaction fee config
rent: Rentrent config
inflation: Inflationinflation config
epoch_schedule: EpochSchedulehow slots map to epochs
cluster_type: ClusterTypenetwork runlevel
Implementations
Sourceimpl GenesisConfig
impl GenesisConfig
pub fn new( accounts: &[(Pubkey, AccountSharedData)], native_instruction_processors: &[(String, Pubkey)], ) -> Self
pub fn hash(&self) -> Hash
pub fn load(ledger_path: &Path) -> Result<Self, Error>
pub fn write(&self, ledger_path: &Path) -> Result<(), Error>
pub fn add_account(&mut self, pubkey: Pubkey, account: AccountSharedData)
pub fn add_native_instruction_processor( &mut self, name: String, program_id: Pubkey, )
pub fn hashes_per_tick(&self) -> Option<u64>
pub fn ticks_per_slot(&self) -> u64
pub fn ns_per_slot(&self) -> u128
pub fn slots_per_year(&self) -> f64