pub struct PohConfig {
pub target_tick_duration: Duration,
pub target_tick_count: Option<u64>,
pub hashes_per_tick: Option<u64>,
}Fields
target_tick_duration: DurationThe target tick rate of the cluster.
target_tick_count: Option<u64>The target total tick count to be produced; used for testing only
hashes_per_tick: Option<u64>How many hashes to roll before emitting the next tick entry. None enables “Low power mode”, which implies:
- sleep for
target_tick_durationinstead of hashing - the number of hashes per tick will be variable
Implementations