pub struct Lockup {
pub unix_timestamp: i64,
pub epoch: u64,
pub custodian: Pubkey,
}Fields
unix_timestamp: i64UnixTimestamp at which this stake will allow withdrawal, unless the transaction is signed by the custodian
epoch: u64epoch height at which this stake will allow withdrawal, unless the transaction is signed by the custodian
custodian: Pubkeycustodian signature on a transaction exempts the operation from lockup constraints
Implementations